
\name{e04jc}
\alias{e04jc}

\title{e04jc: Minimum by quadratic approximation, function of several variables, simple 
bounds, using function values only}

\description{
e04jc is an easy-to-use algorithm that uses methods of quadratic approximation 
to find a minimum of an objective function \eqn{{F}}{F} over \eqn{{x} \in 
{R}^{{n}}}{x \in R^n}, subject to fixed lower and upper bounds on the independent 
variables \eqn{{x}_{{1}} , {x}_{{2}} , \ldots , {x}_{{n}}}{x_1 , x_2 ,  . . .  , x_n}. 
Derivatives of \eqn{{F}}{F} are not required.

The function is intended for functions that are continuous and that have 
continuous first and second derivatives (although it will usually work 
even if the derivatives have occasional discontinuities). Efficiency is 
maintained for large \eqn{{n}}{n}.

}

\usage{
e04jc(objfun, npt, x, bl, bu, rhobeg, rhoend, monfun, maxcal,
      n = nrow(x))
}

\arguments{

\item{objfun}{function

objfun must evaluate the objective function \eqn{{F}}{F} at a specified vector \eqn{{x}}{x}.

\code{(F,INFORM) = objfun(n,x)
}


}
\item{npt}{integer

\eqn{{m}}{m}, the number of interpolation conditions imposed on the quadratic 
approximation at each iteration.


}
\item{x}{double array

An estimate of the position of the minimum. If any component is out-of-bounds 
it is replaced internally by the bound it violates.


}
\item{bl}{double array}
\item{bu}{double array

The fixed vectors of bounds: the lower bounds \eqn{{\ell}}{\ell} and the upper 
bounds \eqn{{u}}{u}, respectively. To signify that a variable is unbounded 
you should choose a large scalar \eqn{{r}}{r} appropriate to your problem, 
then set the lower bound on that variable to \eqn{- {r}}{- r} and the upper 
bound to \eqn{{r}}{r}. For well-scaled problems \eqn{{r} = {r}_{{max}}^{\frac{{1}}{{4}}}}{r = r_max^(1)/(4)} 
may be suitable, where \eqn{{r}_{{max}}}{r_max} denotes the largest positive 
model number (see x02al).


}
\item{rhobeg}{double

An initial lower bound on the value of the trust-region radius.


}
\item{rhoend}{double

A final lower bound on the value of the trust-region radius.


}
\item{monfun}{function

monfun may be used to monitor the optimization process. It is invoked every time a new trust-region radius is chosen.

\code{(INFORM) = monfun(n,nf,x,f,rho)
}


}
\item{maxcal}{integer

The maximum permitted number of calls to objfun.


}
\item{n}{integer: \strong{default} = nrow(x)

\eqn{{n}}{n}, the number of independent variables.


}
}

\details{
R interface to the NAG Fortran routine E04JCF.}

\value{

\item{X}{double array

The lowest point found during the calculations. Thus, if \eqn{\mathrm{ifail} 
=0}{ifail =0} on exit, x is the position of the minimum.


}
\item{F}{double

The function value at the lowest point found (x).


}
\item{NF}{integer

Unless \eqn{\mathrm{ifail} =1}{ifail =1}, \eqn{\mathrm{ifail} =-999}{ifail =-999} 
on exit, the total number of calls made to objfun.


}
\item{IFAIL}{integer

\eqn{\mathrm{ifail} =0}{ifail =0} unless the function detects an error 
or a warning has been flagged (see the Errors section in Fortran library 
documentation).


}
}

\references{
\url{http://www.nag.co.uk/numeric/FL/nagdoc_fl23/pdf/E04/e04jcf.pdf}
}

\author{NAG}

\examples{

ifail <- 0
maxcal <- 500

rhobeg <- 0.1

rhoend <- 1e-06

n <- 4

npt <- 2 * n + 1

infbnd <- sqrt(sqrt(x02al()[["result"]]))


bl <- matrix(c(1, -2, -infbnd, 1), nrow = 4, ncol = 1, 
    byrow = TRUE)



bu <- matrix(c(3, 0, infbnd, 3), nrow = 4, ncol = 1, 
    byrow = TRUE)



x <- matrix(c(3, -1, 0, 1), nrow = 4, ncol = 1, byrow = TRUE)


e04jc_objfun = function(n, x) {
    inform <- 0
    
    f <- (x[1] + 10 \%*\% x[2])^2 + 5 \%*\% (x[3] - x[4])^2 + (x[2] - 
        2 \%*\% x[3])^4 + 10 \%*\% (x[1] - x[4])^4
    list(F = f, INFORM = as.integer(inform))
    
}
e04jc_monfun = function(n, nf, x, f, rho) {
    inform <- 0
    
    writeLines(sprintf("\nNew rho = \%13.5e, number of function evaluations = \%d\n", 
        rho, nf))
    
    
    writeLines(sprintf("Current function value = \%13.5en", 
        f))
    
    
    writeLines(sprintf("The corresponding X is:", 
        "\n"))
    
    
    writeLines(sprintf(" \%13.5e", x, "\n"))
    
    
    writeLines(sprintf("\n", "\n"))
    
    list(INFORM = as.integer(inform))
    
}
ans <- e04jc(e04jc_objfun, npt, x, bl, bu, rhobeg, 
    rhoend, e04jc_monfun, maxcal)


print(ans$X)
print(ans$F)
print(ans$NF)
print(ans$IFAIL) 

}

\keyword{math}

\keyword{optimize}
\concept{bound}
\concept{minimum}
\concept{quadratic approximation}
\concept{BOBYQA}
