
\name{e04xa}
\alias{e04xa}

\title{e04xa: Estimate (using numerical differentiation) gradient and/or Hessian of a 
function}

\description{
e04xa computes an approximation to the gradient vector and/or the Hessian 
matrix for use in conjunction with, or following the use of an optimization 
function (such as e04uf).


}

\usage{
e04xa(msglvl, epsrf, x, mode, objfun, hforw, lwsav, iwsav, rwsav,
      n = nrow(x))
}

\arguments{

\item{msglvl}{integer

Must indicate the amount of intermediate output desired (see the printed 
output description in the Fortran library documentation for a description 
of the printed output). All output is written on the current advisory message 
unit (see x04ab).


}
\item{epsrf}{double

Must define \eqn{{e}_{{R}}}{e_R}, which is intended to be a measure of 
the accuracy with which the problem function \eqn{{F}}{F} can be computed. 
The value of \eqn{{e}_{{R}}}{e_R} should reflect the relative precision 
of \eqn{{1} + \mathrm{abs}({F}\left({x}\right))}{1 + abs(F(x))}, i.e., 
acts as a relative precision when \eqn{\mathrm{abs}({F})}{abs(F)} is large, 
and as an absolute precision when \eqn{\mathrm{abs}({F})}{abs(F)} is small. 
For example, if \eqn{{F}\left({x}\right)}{F(x)} is typically of order \eqn{{1000}}{1000} 
and the first six significant digits are known to be correct, an appropriate 
value for \eqn{{e}_{{R}}}{e_R} would be \eqn{{1.0E-6}}{1.0E-6}.


}
\item{x}{double array

The point \eqn{{x}}{x} at which the derivatives are to be computed.


}
\item{mode}{integer

Indicates which derivatives are required. 

\eqn{mode = {0}}{mode = 0}: The gradient and Hessian diagonal values having 
supplied the objective function via objfun.

\eqn{mode = {1}}{mode = 1}: The Hessian matrix having supplied both the 
objective function and gradients via objfun.

\eqn{mode = {2}}{mode = 2}: The gradient values and Hessian matrix having 
supplied the objective function via objfun.




}
\item{objfun}{function

If \eqn{mode={0}, {2}}{mode=0, 2}, objfun must calculate the objective function; otherwise if \eqn{mode = {1}}{mode = 1}, objfun must calculate the objective function and the gradients.

\code{(MODE,OBJF,OBJGRD) = objfun(mode,n,x,nstate)
}


}
\item{hforw}{double array

The initial trial interval for computing the appropriate partial derivative 
to the \eqn{{j}}{j}th variable.


}
\item{lwsav}{boolean array}
\item{iwsav}{integer array}
\item{rwsav}{double array

These arguments are no longer required by e04xa.
}
\item{n}{integer: \strong{default} = nrow(x)

The number \eqn{{n}}{n} of independent variables.


}
}

\details{
R interface to the NAG Fortran routine E04XAF.}

\value{

\item{MODE}{integer

Is changed \bold{only} if you set mode negative in objfun, i.e., you have 
requested termination of e04xa.


}
\item{HFORW}{double array

\eqn{hforw[{j}]}{hforw[j]} is the best interval found for computing a forward-difference 
approximation to the appropriate partial derivative for the \eqn{{j}}{j}th 
variable.


}
\item{OBJF}{double

The value of the objective function evaluated at the input vector in x.


}
\item{OBJGRD}{double array

If \eqn{mode={0}, {2}}{mode=0, 2}, \eqn{objgrd[{j}]}{objgrd[j]} contains 
the best estimate of the first partial derivative for the \eqn{{j}}{j}th 
variable.


}
\item{HCNTRL}{double array

\eqn{hcntrl[{j}]}{hcntrl[j]} is the best interval found for computing a 
central-difference approximation to the appropriate partial derivative 
for the \eqn{{j}}{j}th variable.


}
\item{H}{double array

If \eqn{mode = {0}}{mode = 0}, the estimated Hessian diagonal elements 
are contained in the first column of this array.


}
\item{IWARN}{integer

\eqn{iwarn = {0}}{iwarn = 0} on successful exit.


}
\item{INFO}{integer array

\eqn{info[{j}]}{info[j]} represents diagnostic information on variable 
\eqn{{j}}{j}. (See the Errors section in Fortran library documentation 
for more details.)


}
\item{IFAIL}{integer

\eqn{\mathrm{ifail} =0}{ifail =0} unless the function detects an error 
or a warning has been flagged (see the Errors section in Fortran library 
documentation).


}
}

\references{
\url{http://www.nag.co.uk/numeric/FL/nagdoc_fl23/pdf/E04/e04xaf.pdf}
}

\author{NAG}

\examples{

optlist <- list()

ifail <- 0
objfun = function(mode, n, x, nstate) {
    
    objgrd <- as.matrix(mat.or.vec(n, 1))
    a <- x[1] + 10 \%*\% x[2]
    b <- x[3] - x[4]
    c <- x[2] - 2 \%*\% x[3]
    d <- x[1] - x[4]
    objf <- a^2 + 5 \%*\% b^2 + c^4 + 10 \%*\% d^4
    
    if (mode == 1) {
        
        objgrd[1] <- 40 \%*\% x[1]^3 + 2 \%*\% x[1] - 120 \%*\% x[4] \%*\% 
            x[1]^2 + 120 \%*\% x[1] \%*\% x[4]^2 + 20 \%*\% x[2] - 
            40 \%*\% x[4]^3
        
        objgrd[2] <- 200 \%*\% x[2] + 20 \%*\% x[1] + 4 \%*\% x[2]^3 + 
            48 \%*\% x[2] \%*\% x[3]^2 - 24 \%*\% x[3] \%*\% x[2]^2 - 
            32 \%*\% x[3]^3
        
        objgrd[3] <- 10 \%*\% x[3] - 10 \%*\% x[4] - 8 \%*\% x[2]^3 + 
            48 \%*\% x[3] \%*\% x[2]^2 - 96 \%*\% x[2] \%*\% x[3]^2 + 
            64 \%*\% x[3]^3
        
        objgrd[4] <- 10 \%*\% x[4] - 10 \%*\% x[3] - 40 \%*\% x[1]^3 + 
            120 \%*\% x[4] \%*\% x[1]^2 - 120 \%*\% x[1] \%*\% x[4]^2 + 
            40 \%*\% x[4]^3
        
    }
    list(MODE = as.integer(mode), OBJF = objf, OBJGRD = as.matrix(objgrd))
}

msglvl <- 0

epsrf <- -1

x <- matrix(c(3, -1, 0, 1), nrow = 4, ncol = 1, byrow = TRUE)



mode <- 0

hforw <- matrix(c(-1, -1, -1, -1), nrow = 4, ncol = 1, 
    byrow = TRUE)



lwsav <- as.matrix(mat.or.vec(120, 1))

iwsav <- as.matrix(mat.or.vec(610, 1))

rwsav <- as.matrix(mat.or.vec(475, 1))

e04xa(msglvl, epsrf, x, mode, objfun, hforw, lwsav, 
    iwsav, rwsav) 

}

\keyword{math}

\keyword{optimize}
\concept{differentiation}
\concept{estimate}
\concept{gradient}
\concept{Hessian}
\concept{numerical}
